<?php
/**
 * DPD France v5.1.1 shipping module for OsCommerce 2.3
 *
 * @category   DPDFrance
 * @package    DPDFrance_Shipping
 * @author     DPD France S.A.S. <ensavoirplus.ecommerce@dpd.fr>
 * @copyright  2015 DPD France S.A.S., société par actions simplifiée, au capital de 18.500.000 euros, dont le siège social est situé 27 Rue du Colonel Pierre Avia - 75015 PARIS, immatriculée au registre du commerce et des sociétés de Paris sous le numéro 444 420 830 
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

class dpdfrworld {
	var $code, $title, $description, $enabled, $num_zones;

	// class constructor
	function dpdfrworld() {
		global $order;

		$this->code = 'dpdfrworld';
		$this->title = MODULE_SHIPPING_DPDFRANCE_WORLD_TEXT_TITLE;
		$this->description = MODULE_SHIPPING_DPDFRANCE_WORLD_TEXT_DESCRIPTION;
		$this->sort_order = MODULE_SHIPPING_DPDFRANCE_WORLD_SORT_ORDER;
		$this->icon = '';
		$this->tax_class = MODULE_SHIPPING_DPDFRANCE_WORLD_TAX_CLASS;
		$this->enabled = ((MODULE_SHIPPING_DPDFRANCE_WORLD_STATUS == 'True') ? true : false);

		// CUSTOMIZE THIS SETTING FOR THE NUMBER OF ZONES NEEDED
		$this->num_zones = 4;

		if ($this->enabled == true){
			$dest_country = $order->delivery['country']['iso_code_2'];

			for ($i=1; $i<=$this->num_zones; $i++) {
				$countries_table = constant('MODULE_SHIPPING_DPDFRANCE_WORLD_COUNTRIES_' . $i);
				$country_zones = preg_split("/[,]/", $countries_table);
				if (in_array($dest_country, $country_zones)){
					$this->enabled = true;
					break;
				}
				else
					$this->enabled = false;
			}
		}
	}

// class methods
	function quote($method = '') {
		global $order, $shipping_weight, $shipping_num_boxes;

		if (MODULE_SHIPPING_DPDFRANCE_WORLD_MODE == 'price')
			$order_total = $this->getShippableTotal();
		else
			$order_total = $shipping_weight;

		$dest_country = $order->delivery['country']['iso_code_2'];
		$dest_zone = 0;
		$error = false;

		for ($i=1; $i<=$this->num_zones; $i++) {
			$countries_table = constant('MODULE_SHIPPING_DPDFRANCE_WORLD_COUNTRIES_' . $i);
			$country_zones = preg_split("/[,]/", $countries_table);
			if (in_array($dest_country, $country_zones)) {
				$dest_zone = $i;
				break;
			}
		}

		if ($dest_zone == 0)
			$error = true;
		else 
		{
			$shipping = -1;
			$zones_cost = constant('MODULE_SHIPPING_DPDFRANCE_WORLD_COST_' . $dest_zone);

			$zones_table = preg_split("/[:,]/" , $zones_cost);
			$size = sizeof($zones_table);
			for ($i=0; $i<$size; $i+=2) {
				if ($order_total <= $zones_table[$i]) {
					if ($this->getShippableTotal() >= constant('MODULE_SHIPPING_DPDFRANCE_WORLD_FRANCO_' . $dest_zone))
						$zones_table[$i+1] = 0;
					$shipping = $zones_table[$i+1];
					$shipping_method = MODULE_SHIPPING_DPDFRANCE_WORLD_TEXT_WAY . ' ' . $dest_country;
				break;
				}
			}

			if (MODULE_SHIPPING_DPDFRANCE_WORLD_MODE == 'weight')
				$shipping = $shipping * $shipping_num_boxes;

			if ($shipping == -1)
				$this->enabled = false;
			else
				$shipping_cost = $shipping + constant('MODULE_SHIPPING_DPDFRANCE_WORLD_HANDLING_' . $dest_zone);
		}

		$this->quotes = array(	'id' => $this->code,
								'module' => MODULE_SHIPPING_DPDFRANCE_WORLD_TEXT_TITLE,
								'methods' => array(array(	'id' => $this->code,
															'title' => $shipping_method,
															'cost' => $shipping_cost)));
		if ($this->tax_class > 0)
			$this->quotes['tax'] = tep_get_tax_rate($this->tax_class, $order->delivery['country']['id'], $order->delivery['zone_id']);
		if (tep_not_null($this->icon)) 
			$this->quotes['icon'] = tep_image($this->icon, $this->title);
		if ($error == true) 
			$this->quotes['error'] = MODULE_SHIPPING_DPDFRANCE_WORLD_INVALID_ZONE;
		return $this->quotes;
	}

	function check() {
		if (!isset($this->_check)) {
			$check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_DPDFRANCE_WORLD_STATUS'");
			$this->_check = tep_db_num_rows($check_query);
		}
		return $this->_check;
	}

    function install() {
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer le module', 'MODULE_SHIPPING_DPDFRANCE_WORLD_STATUS', 'True', 'Activer la livraison DPD Monde', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Classe fiscale', 'MODULE_SHIPPING_DPDFRANCE_WORLD_TAX_CLASS', '0', 'Assigner une classe fiscale', '6', '0', 'tep_get_tax_class_title', 'tep_cfg_pull_down_tax_classes(', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre de tri', 'MODULE_SHIPPING_DPDFRANCE_WORLD_SORT_ORDER', '0', 'Ordonner les transporteurs par ordre croissant', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Méthode de calcul', 'MODULE_SHIPPING_DPDFRANCE_WORLD_MODE', 'weight', 'Calculer les frais de port en fonction du poids ou du montant du panier.', '6', '0', 'tep_cfg_select_option(array(\'weight\', \'price\'), ', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Raison Sociale', 'MODULE_SHIPPING_DPDFRANCE_EXPE_NOM', '".STORE_NAME."', 'Nom d\'expéditeur', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Adresse', 'MODULE_SHIPPING_DPDFRANCE_EXPE_AD1', '', '', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Complément d\'adresse', 'MODULE_SHIPPING_DPDFRANCE_EXPE_AD2', '', '', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Code Postal', 'MODULE_SHIPPING_DPDFRANCE_EXPE_CP', '', '', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ville', 'MODULE_SHIPPING_DPDFRANCE_EXPE_VILLE', '', '', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Téléphone fixe', 'MODULE_SHIPPING_DPDFRANCE_EXPE_TEL', '', '', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Frais fixes', 'MODULE_SHIPPING_DPDFRANCE_WORLD_FRAIS_FIXES', '0', 'Frais fixes (emballage).', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Code Agence DPD', 'MODULE_SHIPPING_DPDFRANCE_WORLD_EXPE_AGENCE', '', 'sur 3 chiffres (ex.: 013).', '6', '0', now())");
		tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('N&deg; Contrat DPD Classic', 'MODULE_SHIPPING_DPDFRANCE_WORLD_EXPE_CARGO', '', 'sur 4 ou 5 chiffres sans code agence, ni tirets, ni zéros devant.', '6', '0', now())");
		tep_db_query("ALTER table ".TABLE_ORDERS." ADD shipping_dpdfrworld_tracking char(128)");    
		for ($i = 1; $i <= $this->num_zones; $i++) {
				$default_countries = '';
			if ($i == 1){
				$default_countries = 'DE,BE,LU,NL';
				$default_rates = '0.5:13.30,1.0:14.50,2.0:15.40,3.0:16.30,5.0:18.10,10.0:20.50,20.0:23.00,30.0:26.00';
			}
			if ($i == 2){
				$default_countries = 'AT,ES,GB,IT';
				$default_rates = '0.5:16.30,1.0:17.50,2.0:18.40,3.0:19.30,5.0:21.10,10.0:23.50,20.0:26.00,30.0:29.00';
			}	  
			if ($i == 3){
				$default_countries = 'HR,DK,EE,HU,IE,LT,PL,PT,CZ,SI,SK,SE';
				$default_rates = '0.5:23.30,1.0:24.50,2.0:25.40,3.0:26.30,5.0:28.10,10.0:30.50,20.0:33.00,30.0:36.00';
			}
			if ($i == 4){
				$default_countries = 'GR,FI,BG,RO';
				$default_rates = '0.5:37.30,1.0:38.50,2.0:39.40,3.0:40.30,5.0:42.10,10.0:44.50,20.0:47.00,30.0:50.00';
			}
			tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Zone " . $i ." Pays', 'MODULE_SHIPPING_DPDFRANCE_WORLD_COUNTRIES_" . $i ."', '" . $default_countries . "', 'Assigner une liste de pays renseignés par leur code ISO sur 2 caractères à la Zone " . $i . ".', '6', '0', now())");
			tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Zone " . $i ." Gestion frais de port', 'MODULE_SHIPPING_DPDFRANCE_WORLD_COST_" . $i ."', '" . $default_rates . "', 'Les frais de port de la Zone " . $i . " sont calculés sur le montant/poids total du panier. Exemple: 25:8.50,50:5.50,etc.. Jusqu\'a 25 facturer 8.50, de 25 à 50 facturer 5.50, etc.', '6', '0', now())");
			tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Zone " . $i ." Handling Fee', 'MODULE_SHIPPING_DPDFRANCE_WORLD_HANDLING_" . $i."', '0', 'Handling Fee for this shipping zone', '6', '0', now())");
			tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Zone " . $i ." Offrir les frais de port à partir d\'un panier supérieur ou égal à', 'MODULE_SHIPPING_DPDFRANCE_WORLD_FRANCO_" . $i."', '0', 'Laisser ce champ vide si vous ne souhaitez pas établir de franco de port', '6', '0', now())");
		}
    }

	function remove() {
		tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
		tep_db_query("ALTER table ".TABLE_ORDERS." DROP shipping_dpdfrworld_tracking");
	}

    function keys() {
		$keys = array('MODULE_SHIPPING_DPDFRANCE_WORLD_STATUS'
					,'MODULE_SHIPPING_DPDFRANCE_WORLD_TAX_CLASS'
					,'MODULE_SHIPPING_DPDFRANCE_WORLD_SORT_ORDER'
					,'MODULE_SHIPPING_DPDFRANCE_WORLD_MODE'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_NOM'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_AD1'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_AD2'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_CP'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_VILLE'
					,'MODULE_SHIPPING_DPDFRANCE_EXPE_TEL'   
					,'MODULE_SHIPPING_DPDFRANCE_WORLD_EXPE_AGENCE'
					,'MODULE_SHIPPING_DPDFRANCE_WORLD_EXPE_CARGO');

		for ($i=1; $i<=$this->num_zones; $i++) {
			$keys[] = 'MODULE_SHIPPING_DPDFRANCE_WORLD_COUNTRIES_' . $i;
			$keys[] = 'MODULE_SHIPPING_DPDFRANCE_WORLD_COST_' . $i;
			$keys[] = 'MODULE_SHIPPING_DPDFRANCE_WORLD_HANDLING_' . $i;
			$keys[] = 'MODULE_SHIPPING_DPDFRANCE_WORLD_FRANCO_' . $i;
		}
		return $keys;
	}

	function getShippableTotal() {
		global $order, $cart, $currencies;

		$order_total = $cart->show_total();

		if ($order->content_type == 'mixed') {
			$order_total = 0;

			for ($i=0, $n=sizeof($order->products); $i<$n; $i++) {
				$order_total += $currencies->calculate_price($order->products[$i]['final_price'], $order->products[$i]['tax'], $order->products[$i]['qty']);

				if (isset($order->products[$i]['attributes'])) {
					reset($order->products[$i]['attributes']);
					while (list($option, $value) = each($order->products[$i]['attributes'])) {
						$virtual_check_query = tep_db_query("select count(*) as total from " . TABLE_PRODUCTS_ATTRIBUTES . " pa, " . TABLE_PRODUCTS_ATTRIBUTES_DOWNLOAD . " pad where pa.products_id = '" . (int)$order->products[$i]['id'] . "' and pa.options_values_id = '" . (int)$value['value_id'] . "' and pa.products_attributes_id = pad.products_attributes_id");
						$virtual_check = tep_db_fetch_array($virtual_check_query);
						if ($virtual_check['total'] > 0)
							$order_total -= $currencies->calculate_price($order->products[$i]['final_price'], $order->products[$i]['tax'], $order->products[$i]['qty']);
					}
				}
			}
		}
		return $order_total;
	}
}
?>
